//
//  ResultViewController.m
//  SampleExplicitApp
//
//  Copyright (c) 2013年 Yahoo Japan Corporation. All rights reserved.
//

#import "ResultViewController.h"
#import "YConnectSDK.h"

// アプリケーションID
static NSString * const CLIENT_ID = @"あなたのアプリケーションID";
// コールバックURL
// (アプリケーションID発行時に登録したURI)
static NSString * const REDIRECT_URI = @"yj-xxxxx://cb";

@interface ResultViewController ()

@end

@implementation ResultViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    return self;
}


- (void)viewDidLoad
{
    [super viewDidLoad];
    
    // コールバックURLから各パラメーターを抽出
    YConnectExplicit *yconnect = [YConnectExplicit getInstance];
    [yconnect parseAuthorizationResponse:self.url customUriScheme:@"yj-xxxxx://" state:yconnect.requestClient.state];
    // 認可コードを取得
    NSString *code = [yconnect getAuthorizationCode];
    
    // Tokenエンドポイントにリクエスト
    [yconnect requestToken:code redirectUri:REDIRECT_URI clientId:CLIENT_ID];
    // アクセストークン、リフレッシュトークン、IDトークンを取得
    NSString *accessTokenString = [yconnect getAccessToken];
    long expiration = [yconnect getAccessTokenExpiration];
    NSString *refreshToken = [yconnect getRefreshToken];
    NSString *idTokenString = [yconnect getIdToken];
    NSLog(@"accessTokenString:%@, expiration:%ld, refreshToken:%@, idTokenString:%@", accessTokenString, expiration, refreshToken, idTokenString);
    
    // CheckTokenエンドポイントにリクエスト
    [yconnect requestCheckIdToken:idTokenString nonce:yconnect.nonce clientId:CLIENT_ID];
    // 復号化されたIDトークン情報を取得
    IdTokenObject *idTokenObject = [yconnect getIdTokenObject];
    NSLog(@"iss:%@", idTokenObject.iss);
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (IBAction)requestUserinfoAction:(id)sender
{
    
    YConnectExplicit *yconnect = [YConnectExplicit getInstance];
    @try {
        NSString *accessTokenString = [yconnect getAccessToken];
        // UserInfoエンドポイントにリクエスト
        [yconnect requestUserInfo:accessTokenString];
        // UserInfo情報を取得
        UserInfoObject *userInfoObject = [yconnect getUserInfoObject];
        NSLog(@"userId:%@", userInfoObject.userId);
    }
    @catch (NSException *exception) {
        if ([exception.reason isEqualToString:@"invalid_token"]) {
            NSLog(@"invalid_token");
            [self refreshAccessToken];
        }
    }

}

- (void)refreshAccessToken {
    YConnectExplicit *yconnect = [YConnectExplicit getInstance];
    NSString *refreshToken = [yconnect getRefreshToken];
    @try {
        [yconnect refreshAccessToken:refreshToken clientId:CLIENT_ID];
        NSString *accessTokenString = [yconnect getAccessToken];
        long expiration = [yconnect getAccessTokenExpiration];
        NSLog(@"accessTokenString:%@, expiration:%ld", accessTokenString, expiration);
    }
    @catch (NSException *exception) {
        if ([exception.reason isEqualToString:@"invalid_grant"]) {
            UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"エラー"
                                                                           message:@"ログインし直してください"
                                                                    preferredStyle:UIAlertControllerStyleAlert];
            UIAlertAction *action = [UIAlertAction actionWithTitle:@"OK" style:UIAlertActionStyleDefault handler:nil];
            [alert addAction:action];
            [self presentViewController:alert animated:YES completion:nil];
        }
    }
}

@end
