//
//  StartViewController.m
//  SampleExplicitApp
//
//  Copyright (c) 2013年 Yahoo Japan Corporation. All rights reserved.
//

#import <SafariServices/SafariServices.h>

#import "StartViewController.h"
#import "ResultViewController.h"
#import "YConnectSDK.h"

// アプリケーションID
static NSString * const CLIENT_ID = @"あなたのアプリケーションID";
// コールバックURL
// (アプリケーションID発行時に登録したURI)
static NSString * const REDIRECT_URI = @"yj-xxxxx://cb";

@interface StartViewController ()

@property (nonatomic, retain) SFSafariViewController *safariViewController;
@property (nonatomic, retain) SFAuthenticationSession *authenticationSession API_AVAILABLE(ios(11.0));

@end

@implementation StartViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

//ログイン用のアクションを作成
- (IBAction)loginAction:(id)sender
{
    // YConnectインスタンス取得
    YConnectExplicit *yconnect = [YConnectExplicit getInstance];
    
    // 各パラメーター初期化
    // リクエストとコールバック間の検証用のランダムな文字列を指定してください
    NSString *state = @"44GC44GC54Sh5oOF";
    NSString *responseType = [OAuth2ResponseType CODE_IDTOKEN];
    // リプレイアタック対策のランダムな文字列を指定してください
    NSString *nonce = @"U0FNTCBpcyBEZWFkLg==";
    NSString *display = [OIDCDisplay SMART_PHONE];
    NSString *prompt = [OIDCPrompt EMPTY];
    NSString *scope = [NSString stringWithFormat:@"%@ %@ %@ %@", [OIDCScope OPENID], [OIDCScope PROFILE], [OIDCScope EMAIL], [OIDCScope ADDRESS]];
    
    // 各パラメーターを設定
    yconnect = [yconnect initWithClientId:CLIENT_ID redirectUri:REDIRECT_URI state:state responseType:responseType display:display prompt:prompt scope:scope nonce:nonce];
    // AuthorizationエンドポイントのURLを生成
    NSURL *url = [yconnect generateAuthorizationUri];
    self.url = url;
    
    // 認証画面に遷移
    [self openURL:url];
}

/**
 * iOSのバージョンに応じた方法でauthorizationエンドポイントにリクエストする
 * @param url リクエストURL
 **/
- (void)openURL:(NSURL *)url
{
    // iOS11以上ならSFAuthenticationSessionを使って画面遷移する
    if (@available(iOS 11.0, *)) {
        self.authenticationSession = [[SFAuthenticationSession alloc] initWithURL:url callbackURLScheme:REDIRECT_URI completionHandler:^(NSURL * _Nullable callbackURL, NSError * _Nullable error) {
            id delegate = [[UIApplication sharedApplication] delegate];
            [delegate application:[UIApplication sharedApplication] openURL:callbackURL options:@{}];
        }];
        [self.authenticationSession start];
        return;
    }

    // iOS9以上11未満ならSFSafariViewContollerを使って画面遷移する
    if (@available(iOS 9.0, *)) {
        self.safariViewController = [[SFSafariViewController alloc] initWithURL:url];
        [self presentViewController:self.safariViewController animated:YES completion:nil];
        return;
    }

    NSLog(@"iOS8 or less cannot open URL with SFAuthenticationSession or SFSafariViewController");
}

-(void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ( [[segue identifier] isEqualToString:@"StartToResult"] ) {
        ResultViewController *resultViewController = [segue destinationViewController];
        //コールバックURLをViewControllerに渡す
        resultViewController.url = self.url;
    }
}

@end
