//
//  AuthorizationException.m
//  YConnectSDKforIOSLibrary
//
//  Copyright (c) 2012年 Yahoo Japan Corporation. All rights reserved.
//

#import "AuthorizationException.h"

@implementation AuthorizationException
/**
 * 初期化
 * @param NSString *name
 * @param NSString *reason
 * @param NSDictionary *userInfo
 * @return id
 **/
- (id)initWithName:(NSString*)name reason:(NSString*)reason userInfo:(NSDictionary*)userInfo {
    self =  [super initWithName:name reason:reason userInfo:userInfo];
    return self;
}

/**
 * 文字列化
 * @return NSString *
 **/
- (NSString *)toString {
    NSString *error = [NSString stringWithFormat:@"name:%@ reason:%@ userInfo:%@", [self name], [self reason], [self userInfo]];
    return error;
}

/**
 * 不正なリクエストによる例外か
 * @return BOOL
 **/
- (BOOL)isInvalidRequest {
    if ([@"invalid_request" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
/**
 * 認可されていないクライアントによる例外か
 * @return BOOL
 **/
- (BOOL)isUnauthorizedClient {
    if ([@"unauthorized_client" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
/**
 * アクセスが拒否されたことによる例外か
 * @return BOOL
 **/
- (BOOL)isAccessDenied {
    if ([@"access_denied" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
/**
 * サポートされていないレスポンス形式による例外か
 * @return BOOL
 **/
- (BOOL)isUnsupportedResponseType {
    if ([@"unsupported_response_type" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
/**
 * 不正なスコープによる例外か
 * @return BOOL
 **/
- (BOOL)isInvalidScope {
    if ([@"invalid_scope" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
/**
 * サーバーエラーによる例外か
 * @return BOOL
 **/
- (BOOL)isServerError {
    if ([@"server_error" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
/**
 * 一時的に利用不可能なことによる例外か
 * @return BOOL
 **/
- (BOOL)isTemporarilyUnabailable {
    if ([@"temporarily_available" isEqualToString:[self reason]]) {
        return true;
    }
    return false;
}
@end
