//
//  AuthorizationRequestClient.m
//  YConnectSDKforIOSLibrary
//
//  Copyright (c) 2012年 Yahoo Japan Corporation. All rights reserved.
//

#import "AuthorizationRequestClient.h"
#import "HttpParameters.h"

@interface AuthorizationRequestClient()
@property (nonatomic, retain) NSString *endpointUri;
@property (nonatomic, retain) NSString *clientId;
@property (nonatomic, retain) NSURL *requestUri;
@property (nonatomic, retain) HttpParameters *requestParameter; //追加

@end

@implementation AuthorizationRequestClient

/**
 * 初期化
 * @param NSString *endpointUri
 * @param NSString *clientId
 * @return id
 **/
- (id)initWithEndpointUri:(NSString *)endpointUri clientId:(NSString *)clientId {
    self = [super init];
    if (self) {
        _endpointUri = endpointUri;
        _clientId = clientId;
        _requestUri = [[NSURL alloc] init];
        _requestParameter = [[HttpParameters alloc] init];
        _dic = nil;
    }
    return self;
}
/**
 * AuthへのリクエストURIを生成
 * @return NSURL *
 **/
- (NSURL *)generateAuthorizationUri {    
    [self setParameter:@"client_id" value:self.clientId];
    [self setParameter:@"response_type" value:self.responseType];
    [self setParameter:@"state" value:self.state];
    [self setParameter:@"redirect_uri" value:self.redirectUri];
    NSString *uriString = [NSString stringWithFormat:@"%@?%@", self.endpointUri, [self.requestParameter toQueryString]];
    
    //その他のパラメータ
    //辞書の全キーをソートして取得
    NSArray *keys = [[self.dic allKeys] sortedArrayUsingSelector:@selector(caseInsensitiveCompare:)];
    for (id param in keys) {
        //パラメータ追加
        uriString = [uriString stringByAppendingFormat:@"&%@=%@", param, [self.dic objectForKey:param]];
    }

    NSLog(@"%@: %@", NSStringFromClass([self class]), uriString);
    
    //空白のみをURLエンコード後の文字へ変更
    uriString = [uriString stringByReplacingOccurrencesOfString:@" " withString:@"%20"];
    
    self.requestUri = [NSURL URLWithString:uriString];
    return self.requestUri;
}
/**
 * パラメータをセット
 * @param NSString *name
 * @param NSString *value
 **/
- (void)setParameter:(NSString *)name value:(NSString *)value {
    [self.requestParameter setValue:value forKey:name];
}
/**
 * キーでパラメータの値をゲット
 * @param NSString *name
 * @return NSString *
 **/
- (NSString *)getParameterValue:(NSString *)name {
    return [self.requestParameter objectForKey:name];
}

@end
