//
//  ImplicitCallbackUriParser.m
//  YConnectSDKforIOSLibrary
//
//  Copyright (c) 2012年 Yahoo Japan Corporation. All rights reserved.
//

#import "ImplicitCallbackUriParser.h"

/**
 * implicit flowでのコールバック処理
 **/
@implementation ImplicitCallbackUriParser

/**
 * 初期化
 * @param NSURL *redirectUri
 * @param NSString *callBackUri
 * @return id
 **/
- (id)initWithRedirectUri:(NSURL *)redirectUri callBackUri:(NSString *)callBackUri {
    self = [super initWithRedirectUri:redirectUri callBackUri:callBackUri];
    return self;
}
/**
 * アクセストークンを取得
 * @param NSString *state Authリクエスト時のState値
 * @return BearerToken *
 * @throw AuthorizationException アクセストークンまたは有効期限がないことによる例外
 * @throw AuthorizationException State値が一致しないことによる例外
 **/
- (BearerToken *)getAccessToken:(NSString *)state {
    if ([state isEqualToString:[parameters objectForKey:@"state"]]) {
        NSString *accessTokenString = [parameters objectForKey:@"access_token"];
        NSString *expirationString = [parameters objectForKey:@"expires_in"];
        if (accessTokenString != nil && expirationString != nil) {
            long expiration = [expirationString longLongValue];
            return [[BearerToken alloc] initWithAccessToken:accessTokenString expiration:expiration];
        } else {
            NSLog(@"%@: No access_token or expires_in parameters.", NSStringFromClass([self class]));
            //例外をスロー
            @throw [[AuthorizationException alloc] initWithName:@"NoAccessTokenOrExpiresInParameters" reason:@"No access_token or expires_in parameters." userInfo:nil];
        }
    } else {
        NSLog(@"%@: Not match state.", NSStringFromClass([self class]));
        //例外をスロー
        @throw [[AuthorizationException alloc] initWithName:@"NotMatchState" reason:@"Not match state." userInfo:nil];
    }
}

@end
