//
//  RefreshTokenClient.m
//  YConnectSDKforIOSLibrary
//
//  Copyright (c) 2012年 Yahoo Japan Corporation. All rights reserved.
//

#import "RefreshTokenClient.h"
@implementation RefreshTokenClient 

//初期化
- (id)initWithEndpointUrl:(NSString *)endpointUrl refreshToken:(NSString *)refreshToken clientId:(NSString *)clientId {
    self = [super initWithEndpointUrl:endpointUrl clientId:clientId];
    _refreshToken = refreshToken;
    return self;
}

- (void)fetch {
    HttpParameters *parameters = [[HttpParameters alloc] init];
    [parameters setValue:[OAuth2GrantType REFRESH_TOKEN] forKey:@"grant_type"];
    [parameters setValue:self.refreshToken forKey:@"refresh_token"];
    [parameters setValue:self.clientId forKey:@"client_id"];

    HttpHeaders *requestHeaders = [[HttpHeaders alloc] init];
    [requestHeaders setValue:@"application/x-www-form-urlencoded;charset=UTF-8" forKey:@"Content-Type"];
    [requestHeaders setValue:self.clientId forKey:@"X-Yahoo-YConnect-Client-ID"];

    HttpClient *client = [[HttpClient alloc] init];
    [client requestPost:self.endpointUrl parameters:parameters requestHeaders:requestHeaders];

    NSLog(@"%@: %@", NSStringFromClass([self class]), client.responseBody);
    NSLog(@"%@: %@", NSStringFromClass([self class]), [client.responseHeaders toHeaderString]);

    int statusCode = [client getStatusCode];
    
    if (statusCode == 503) {
        @throw [[TokenException alloc] initWithName:@"" reason:@"temporarily_available" userInfo:nil];
    }
    
    NSError *error = nil;
    NSString *json = client.responseBody;
    NSDictionary *jsonObject = [NSJSONSerialization
                                JSONObjectWithData:[json dataUsingEncoding:NSUTF8StringEncoding]
                                options:NSJSONReadingAllowFragments
                                error:&error];
    
    if (error) {
        @throw [[TokenException alloc] initWithName:@"" reason:@"An unexpected error has occurred." userInfo:nil];
    }
    
    if (statusCode == 200) {
        NSString *accessTokenString = [jsonObject objectForKey:@"access_token"];
        long expiresIn = [[jsonObject objectForKey:@"expires_in"] longLongValue];
        self.accessToken = [[BearerToken alloc] initWithAccessToken:accessTokenString expiration:expiresIn refreshToken:self.refreshToken];
        return;
    }
    
    NSString *errorString = [jsonObject objectForKey:@"error"];
    if([errorString length] > 0) {
        NSLog(@"%@: %@ / %@", NSStringFromClass([self class]), error, [jsonObject objectForKey:@"error_description"]);
        @throw [[TokenException alloc] initWithName:@"ResponseBodyContainsErrorMessage" reason:errorString userInfo:nil];
    } else {
        NSLog(@"%@: An unexpected error has occurred.", NSStringFromClass([self class]));
        @throw [[TokenException alloc] initWithName:@"" reason:@"An unexpected error has occurred." userInfo:nil];
    }    
}

- (id)getAccessToken {
    return self.accessToken;
}

@end
